@@ -4,7 +4,11 @@ from pathlib import Path
 def auto_create_folder( default_path = Path( os.environ[ 'USERPROFILE' ], "Desktop" ), folder_extend = None ):
     default_path = Path( default_path )
     default_list = str( default_path ).split( "\\" )
-    default_list.remove( "" )
+    for elem in default_list:
+        if elem == "":
+            default_list.remove( "" )
+        else:
+            pass
     print( default_list )
 
     folder_path = Path( default_path, folder_extend )
